<?php

namespace Drupal\google_pubsub\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\google_pubsub\Services\PubSubServiceInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Controller to handle actions for Google PubSub topics.
 */
class PubSubTopicController extends ControllerBase {

  /**
   * The PubSub service.
   *
   * @var \Drupal\google_pubsub\Services\PubSubServiceInterface
   */
  protected $pubSubService;

  /**
   * Constructs a PubSubDashboardController object.
   *
   * @param \Drupal\google_pubsub\Services\PubSubServiceInterface $pubSubService
   *   The PubSub service.
   */
  public function __construct(PubSubServiceInterface $pubSubService) {
    $this->pubSubService = $pubSubService;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('google_pubsub.pub_sub_service')
    );
  }

  /**
   * Add topic page.
   *
   * @return array
   *   A render array.
   */
  public function addTopic() {
    return $this->formBuilder()->getForm('Drupal\google_pubsub\Form\AddTopicForm');
  }

  /**
   * Delete a topic.
   */
  public function deleteTopic($topicName) {
    // @phpstan-ignore-next-line
    return $this->formBuilder()->getForm('Drupal\google_pubsub\Form\DeleteTopicConfirmForm', $topicName);
  }

  /**
   * Displays the list of PubSub topics.
   */
  public function topics() {
    $topics = $this->pubSubService->listTopics();
    $project_id = $this->config('google_pubsub.settings')->get('project_id');
    $topic_names = [];
    foreach ($topics as $topic) {
      // $topic_names[] = $topic->name();
      $topic_names[] = str_replace('projects/' . $project_id . '/topics/', '', $topic->name());
    }
    return [
      '#theme' => 'google_pubsub_topics',
      '#topics' => $topic_names,
    ];
  }

}
