<?php

namespace Drupal\google_pubsub\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\google_pubsub\Services\PubSubServiceInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Form to add a PubSub Subscription.
 */
class AddSubscriptionForm extends FormBase {

  /**
   * The topic name.
   *
   * @var string
   */
  protected $topicName;

  /**
   * The PubSub service.
   *
   * @var \Drupal\google_pubsub\Services\PubSubServiceInterface
   */
  protected $pubSubService;

  /**
   * Constructs a new AddSubscriptionForm.
   *
   * @param \Drupal\google_pubsub\Services\PubSubServiceInterface $pubSubService
   *   The PubSub service.
   */
  public function __construct(PubSubServiceInterface $pubSubService) {
    $this->pubSubService = $pubSubService;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('google_pubsub.pub_sub_service')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'google_pubsub_add_subscription_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, $topicName = NULL) {
    $this->topicName = $topicName;
    $form['name'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Subscription Name'),
      '#required' => TRUE,
    ];

    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Add Subscription'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $subscription_name = $form_state->getValue('name');

    try {
      $this->pubSubService->createSubscription($subscription_name, $this->topicName);
      $this->messenger()->addMessage($this->t('The Subscription %name has been created.', ['%name' => $subscription_name]));
    }
    catch (\Exception $e) {
      $this->messenger()->addError($this->t('Failed to create the Subscription %name: %error', [
        '%name' => $subscription_name,
        '%error' => $e->getMessage(),
      ]));
    }
    $form_state->setRedirect('google_pubsub.subscriptions', ["topicName" => $this->topicName]);
  }

}
