<?php

namespace Drupal\google_pubsub\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\google_pubsub\Services\PubSubServiceInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Form to add a PubSub topic.
 */
class AddTopicForm extends FormBase {

  /**
   * The PubSub service.
   *
   * @var \Drupal\google_pubsub\Services\PubSubServiceInterface
   */
  protected $pubSubService;

  /**
   * Constructs a new AddTopicForm.
   *
   * @param \Drupal\google_pubsub\Services\PubSubServiceInterface $pubSubService
   *   The PubSub service.
   */
  public function __construct(PubSubServiceInterface $pubSubService) {
    $this->pubSubService = $pubSubService;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('google_pubsub.pub_sub_service')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'google_pubsub_add_topic_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['name'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Topic Name'),
      '#required' => TRUE,
    ];

    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Add Topic'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $name = $form_state->getValue('name');

    try {
      $this->pubSubService->createTopic($name);
      $this->messenger()->addMessage($this->t('The topic %name has been created.', ['%name' => $name]));
    }
    catch (\Exception $e) {
      $this->messenger()->addError($this->t('Failed to create the topic %name: %error', [
        '%name' => $name,
        '%error' => $e->getMessage(),
      ]));
    }
    $form_state->setRedirect('google_pubsub.topics');
  }

}
