<?php

namespace Drupal\google_pubsub\Form;

use Drupal\Core\Form\ConfirmFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Drupal\google_pubsub\Services\PubSubServiceInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Form to confirm the deletion of a PubSub topic.
 */
class DeleteTopicConfirmForm extends ConfirmFormBase {

  /**
   * The PubSub service.
   *
   * @var \Drupal\google_pubsub\Services\PubSubServiceInterface
   */
  protected $pubSubService;

  /**
   * The topic name.
   *
   * @var string
   */
  protected $topicName;

  /**
   * Constructs a new DeleteTopicConfirmForm.
   *
   * @param \Drupal\google_pubsub\Services\PubSubServiceInterface $pubSubService
   *   The PubSub service.
   */
  public function __construct(PubSubServiceInterface $pubSubService) {
    $this->pubSubService = $pubSubService;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('google_pubsub.pub_sub_service')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'google_pubsub_delete_topic_confirm_form';
  }

  /**
   * {@inheritdoc}
   */
  public function getQuestion() {
    return $this->t('Are you sure you want to delete the topic %topic?', ['%topic' => $this->topicName]);
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelUrl() {
    return new Url('google_pubsub.topics');
  }

  /**
   * {@inheritdoc}
   */
  public function getDescription() {
    return $this->t('This action cannot be undone.');
  }

  /**
   * {@inheritdoc}
   */
  public function getConfirmText() {
    return $this->t('Delete');
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, $topicName = NULL) {
    $this->topicName = $topicName;
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    try {
      $this->pubSubService->deleteTopic($this->topicName);
      $this->messenger()->addMessage($this->t('The topic %topic has been deleted.', ['%topic' => $this->topicName]));
    }
    catch (\Exception $e) {
      $this->messenger()->addError($this->t('Failed to delete the topic %topic: %error', [
        '%topic' => $this->topicName,
        '%error' => $e->getMessage(),
      ]));
    }
    $form_state->setRedirect('google_pubsub.topics');
  }

}
